@@ -23,16 +23,16 @@ from aliyunsdknas.endpoint import endpoint_data
 class CancelAutoSnapshotPolicyRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'NAS', '2017-06-26', 'CancelAutoSnapshotPolicy')
+		RpcRequest.__init__(self, 'NAS', '2017-06-26', 'CancelAutoSnapshotPolicy','NAS')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_FileSystemIds(self):
+	def get_FileSystemIds(self): # String
 		return self.get_query_params().get('FileSystemIds')
 
-	def set_FileSystemIds(self,FileSystemIds):
-		self.add_query_param('FileSystemIds',FileSystemIds)
\ No newline at end of file
+	def set_FileSystemIds(self, FileSystemIds):  # String
+		self.add_query_param('FileSystemIds', FileSystemIds)
