@@ -23,34 +23,31 @@ from aliyunsdknas.endpoint import endpoint_data
 class CancelDirQuotaRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'NAS', '2017-06-26', 'CancelDirQuota')
+		RpcRequest.__init__(self, 'NAS', '2017-06-26', 'CancelDirQuota','NAS')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_UserId(self):
+	def get_UserId(self): # String
 		return self.get_query_params().get('UserId')
 
-	def set_UserId(self,UserId):
-		self.add_query_param('UserId',UserId)
-
-	def get_Path(self):
+	def set_UserId(self, UserId):  # String
+		self.add_query_param('UserId', UserId)
+	def get_Path(self): # String
 		return self.get_query_params().get('Path')
 
-	def set_Path(self,Path):
-		self.add_query_param('Path',Path)
-
-	def get_FileSystemId(self):
+	def set_Path(self, Path):  # String
+		self.add_query_param('Path', Path)
+	def get_FileSystemId(self): # String
 		return self.get_query_params().get('FileSystemId')
 
-	def set_FileSystemId(self,FileSystemId):
-		self.add_query_param('FileSystemId',FileSystemId)
-
-	def get_UserType(self):
+	def set_FileSystemId(self, FileSystemId):  # String
+		self.add_query_param('FileSystemId', FileSystemId)
+	def get_UserType(self): # String
 		return self.get_query_params().get('UserType')
 
-	def set_UserType(self,UserType):
-		self.add_query_param('UserType',UserType)
\ No newline at end of file
+	def set_UserType(self, UserType):  # String
+		self.add_query_param('UserType', UserType)
