@@ -23,16 +23,16 @@ from aliyunsdknas.endpoint import endpoint_data
 class CancelLifecycleRetrieveJobRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'NAS', '2017-06-26', 'CancelLifecycleRetrieveJob','nas')
+		RpcRequest.__init__(self, 'NAS', '2017-06-26', 'CancelLifecycleRetrieveJob','NAS')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_JobId(self):
+	def get_JobId(self): # String
 		return self.get_query_params().get('JobId')
 
-	def set_JobId(self,JobId):
-		self.add_query_param('JobId',JobId)
\ No newline at end of file
+	def set_JobId(self, JobId):  # String
+		self.add_query_param('JobId', JobId)
