@@ -23,34 +23,31 @@ from aliyunsdknas.endpoint import endpoint_data
 class CreateRecycleBinRestoreJobRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'NAS', '2017-06-26', 'CreateRecycleBinRestoreJob','nas')
+		RpcRequest.__init__(self, 'NAS', '2017-06-26', 'CreateRecycleBinRestoreJob','NAS')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ClientToken(self):
+	def get_ClientToken(self): # String
 		return self.get_query_params().get('ClientToken')
 
-	def set_ClientToken(self,ClientToken):
-		self.add_query_param('ClientToken',ClientToken)
-
-	def get_FileSystemId(self):
+	def set_ClientToken(self, ClientToken):  # String
+		self.add_query_param('ClientToken', ClientToken)
+	def get_FileSystemId(self): # String
 		return self.get_query_params().get('FileSystemId')
 
-	def set_FileSystemId(self,FileSystemId):
-		self.add_query_param('FileSystemId',FileSystemId)
-
-	def get_FileId(self):
+	def set_FileSystemId(self, FileSystemId):  # String
+		self.add_query_param('FileSystemId', FileSystemId)
+	def get_FileId(self): # String
 		return self.get_query_params().get('FileId')
 
-	def set_FileId(self,FileId):
-		self.add_query_param('FileId',FileId)
-
-	def get_TargetFileId(self):
+	def set_FileId(self, FileId):  # String
+		self.add_query_param('FileId', FileId)
+	def get_TargetFileId(self): # String
 		return self.get_query_params().get('TargetFileId')
 
-	def set_TargetFileId(self,TargetFileId):
-		self.add_query_param('TargetFileId',TargetFileId)
\ No newline at end of file
+	def set_TargetFileId(self, TargetFileId):  # String
+		self.add_query_param('TargetFileId', TargetFileId)
