@@ -23,16 +23,16 @@ from aliyunsdknas.endpoint import endpoint_data
 class DeleteAutoSnapshotPolicyRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'NAS', '2017-06-26', 'DeleteAutoSnapshotPolicy')
+		RpcRequest.__init__(self, 'NAS', '2017-06-26', 'DeleteAutoSnapshotPolicy','NAS')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_AutoSnapshotPolicyId(self):
+	def get_AutoSnapshotPolicyId(self): # String
 		return self.get_query_params().get('AutoSnapshotPolicyId')
 
-	def set_AutoSnapshotPolicyId(self,AutoSnapshotPolicyId):
-		self.add_query_param('AutoSnapshotPolicyId',AutoSnapshotPolicyId)
\ No newline at end of file
+	def set_AutoSnapshotPolicyId(self, AutoSnapshotPolicyId):  # String
+		self.add_query_param('AutoSnapshotPolicyId', AutoSnapshotPolicyId)
