@@ -23,22 +23,21 @@ from aliyunsdknas.endpoint import endpoint_data
 class DeleteMountTargetRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'NAS', '2017-06-26', 'DeleteMountTarget')
+		RpcRequest.__init__(self, 'NAS', '2017-06-26', 'DeleteMountTarget','NAS')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_FileSystemId(self):
+	def get_FileSystemId(self): # String
 		return self.get_query_params().get('FileSystemId')
 
-	def set_FileSystemId(self,FileSystemId):
-		self.add_query_param('FileSystemId',FileSystemId)
-
-	def get_MountTargetDomain(self):
+	def set_FileSystemId(self, FileSystemId):  # String
+		self.add_query_param('FileSystemId', FileSystemId)
+	def get_MountTargetDomain(self): # String
 		return self.get_query_params().get('MountTargetDomain')
 
-	def set_MountTargetDomain(self,MountTargetDomain):
-		self.add_query_param('MountTargetDomain',MountTargetDomain)
\ No newline at end of file
+	def set_MountTargetDomain(self, MountTargetDomain):  # String
+		self.add_query_param('MountTargetDomain', MountTargetDomain)
