@@ -23,16 +23,16 @@ from aliyunsdknas.endpoint import endpoint_data
 class DeleteSnapshotRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'NAS', '2017-06-26', 'DeleteSnapshot')
+		RpcRequest.__init__(self, 'NAS', '2017-06-26', 'DeleteSnapshot','NAS')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_SnapshotId(self):
+	def get_SnapshotId(self): # String
 		return self.get_query_params().get('SnapshotId')
 
-	def set_SnapshotId(self,SnapshotId):
-		self.add_query_param('SnapshotId',SnapshotId)
\ No newline at end of file
+	def set_SnapshotId(self, SnapshotId):  # String
+		self.add_query_param('SnapshotId', SnapshotId)
