@@ -23,40 +23,36 @@ from aliyunsdknas.endpoint import endpoint_data
 class DescribeAutoSnapshotTasksRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'NAS', '2017-06-26', 'DescribeAutoSnapshotTasks')
+		RpcRequest.__init__(self, 'NAS', '2017-06-26', 'DescribeAutoSnapshotTasks','NAS')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_FileSystemType(self):
+	def get_FileSystemType(self): # String
 		return self.get_query_params().get('FileSystemType')
 
-	def set_FileSystemType(self,FileSystemType):
-		self.add_query_param('FileSystemType',FileSystemType)
-
-	def get_PageNumber(self):
+	def set_FileSystemType(self, FileSystemType):  # String
+		self.add_query_param('FileSystemType', FileSystemType)
+	def get_PageNumber(self): # Integer
 		return self.get_query_params().get('PageNumber')
 
-	def set_PageNumber(self,PageNumber):
-		self.add_query_param('PageNumber',PageNumber)
-
-	def get_PageSize(self):
+	def set_PageNumber(self, PageNumber):  # Integer
+		self.add_query_param('PageNumber', PageNumber)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_FileSystemIds(self):
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
+	def get_FileSystemIds(self): # String
 		return self.get_query_params().get('FileSystemIds')
 
-	def set_FileSystemIds(self,FileSystemIds):
-		self.add_query_param('FileSystemIds',FileSystemIds)
-
-	def get_AutoSnapshotPolicyIds(self):
+	def set_FileSystemIds(self, FileSystemIds):  # String
+		self.add_query_param('FileSystemIds', FileSystemIds)
+	def get_AutoSnapshotPolicyIds(self): # String
 		return self.get_query_params().get('AutoSnapshotPolicyIds')
 
-	def set_AutoSnapshotPolicyIds(self,AutoSnapshotPolicyIds):
-		self.add_query_param('AutoSnapshotPolicyIds',AutoSnapshotPolicyIds)
\ No newline at end of file
+	def set_AutoSnapshotPolicyIds(self, AutoSnapshotPolicyIds):  # String
+		self.add_query_param('AutoSnapshotPolicyIds', AutoSnapshotPolicyIds)
