@@ -23,40 +23,36 @@ from aliyunsdknas.endpoint import endpoint_data
 class DescribeMountedClientsRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'NAS', '2017-06-26', 'DescribeMountedClients')
+		RpcRequest.__init__(self, 'NAS', '2017-06-26', 'DescribeMountedClients','NAS')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_PageNumber(self):
+	def get_PageNumber(self): # Integer
 		return self.get_query_params().get('PageNumber')
 
-	def set_PageNumber(self,PageNumber):
-		self.add_query_param('PageNumber',PageNumber)
-
-	def get_ClientIP(self):
+	def set_PageNumber(self, PageNumber):  # Integer
+		self.add_query_param('PageNumber', PageNumber)
+	def get_ClientIP(self): # String
 		return self.get_query_params().get('ClientIP')
 
-	def set_ClientIP(self,ClientIP):
-		self.add_query_param('ClientIP',ClientIP)
-
-	def get_PageSize(self):
+	def set_ClientIP(self, ClientIP):  # String
+		self.add_query_param('ClientIP', ClientIP)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_FileSystemId(self):
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
+	def get_FileSystemId(self): # String
 		return self.get_query_params().get('FileSystemId')
 
-	def set_FileSystemId(self,FileSystemId):
-		self.add_query_param('FileSystemId',FileSystemId)
-
-	def get_MountTargetDomain(self):
+	def set_FileSystemId(self, FileSystemId):  # String
+		self.add_query_param('FileSystemId', FileSystemId)
+	def get_MountTargetDomain(self): # String
 		return self.get_query_params().get('MountTargetDomain')
 
-	def set_MountTargetDomain(self,MountTargetDomain):
-		self.add_query_param('MountTargetDomain',MountTargetDomain)
\ No newline at end of file
+	def set_MountTargetDomain(self, MountTargetDomain):  # String
+		self.add_query_param('MountTargetDomain', MountTargetDomain)
