@@ -23,58 +23,51 @@ from aliyunsdknas.endpoint import endpoint_data
 class DescribeSnapshotsRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'NAS', '2017-06-26', 'DescribeSnapshots')
+		RpcRequest.__init__(self, 'NAS', '2017-06-26', 'DescribeSnapshots','NAS')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_SnapshotIds(self):
+	def get_SnapshotIds(self): # String
 		return self.get_query_params().get('SnapshotIds')
 
-	def set_SnapshotIds(self,SnapshotIds):
-		self.add_query_param('SnapshotIds',SnapshotIds)
-
-	def get_SnapshotName(self):
+	def set_SnapshotIds(self, SnapshotIds):  # String
+		self.add_query_param('SnapshotIds', SnapshotIds)
+	def get_SnapshotName(self): # String
 		return self.get_query_params().get('SnapshotName')
 
-	def set_SnapshotName(self,SnapshotName):
-		self.add_query_param('SnapshotName',SnapshotName)
-
-	def get_FileSystemType(self):
+	def set_SnapshotName(self, SnapshotName):  # String
+		self.add_query_param('SnapshotName', SnapshotName)
+	def get_FileSystemType(self): # String
 		return self.get_query_params().get('FileSystemType')
 
-	def set_FileSystemType(self,FileSystemType):
-		self.add_query_param('FileSystemType',FileSystemType)
-
-	def get_PageNumber(self):
+	def set_FileSystemType(self, FileSystemType):  # String
+		self.add_query_param('FileSystemType', FileSystemType)
+	def get_PageNumber(self): # Integer
 		return self.get_query_params().get('PageNumber')
 
-	def set_PageNumber(self,PageNumber):
-		self.add_query_param('PageNumber',PageNumber)
-
-	def get_PageSize(self):
+	def set_PageNumber(self, PageNumber):  # Integer
+		self.add_query_param('PageNumber', PageNumber)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_FileSystemId(self):
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
+	def get_FileSystemId(self): # String
 		return self.get_query_params().get('FileSystemId')
 
-	def set_FileSystemId(self,FileSystemId):
-		self.add_query_param('FileSystemId',FileSystemId)
-
-	def get_SnapshotType(self):
+	def set_FileSystemId(self, FileSystemId):  # String
+		self.add_query_param('FileSystemId', FileSystemId)
+	def get_SnapshotType(self): # String
 		return self.get_query_params().get('SnapshotType')
 
-	def set_SnapshotType(self,SnapshotType):
-		self.add_query_param('SnapshotType',SnapshotType)
-
-	def get_Status(self):
+	def set_SnapshotType(self, SnapshotType):  # String
+		self.add_query_param('SnapshotType', SnapshotType)
+	def get_Status(self): # String
 		return self.get_query_params().get('Status')
 
-	def set_Status(self,Status):
-		self.add_query_param('Status',Status)
\ No newline at end of file
+	def set_Status(self, Status):  # String
+		self.add_query_param('Status', Status)
