@@ -23,28 +23,26 @@ from aliyunsdknas.endpoint import endpoint_data
 class DescribeStoragePackagesRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'NAS', '2017-06-26', 'DescribeStoragePackages')
+		RpcRequest.__init__(self, 'NAS', '2017-06-26', 'DescribeStoragePackages','NAS')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_UseUTCDateTime(self):
+	def get_UseUTCDateTime(self): # Boolean
 		return self.get_query_params().get('UseUTCDateTime')
 
-	def set_UseUTCDateTime(self,UseUTCDateTime):
-		self.add_query_param('UseUTCDateTime',UseUTCDateTime)
-
-	def get_PageNumber(self):
+	def set_UseUTCDateTime(self, UseUTCDateTime):  # Boolean
+		self.add_query_param('UseUTCDateTime', UseUTCDateTime)
+	def get_PageNumber(self): # Integer
 		return self.get_query_params().get('PageNumber')
 
-	def set_PageNumber(self,PageNumber):
-		self.add_query_param('PageNumber',PageNumber)
-
-	def get_PageSize(self):
+	def set_PageNumber(self, PageNumber):  # Integer
+		self.add_query_param('PageNumber', PageNumber)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
\ No newline at end of file
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
