@@ -23,46 +23,41 @@ from aliyunsdknas.endpoint import endpoint_data
 class ListDirectoriesAndFilesRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'NAS', '2017-06-26', 'ListDirectoriesAndFiles','nas')
+		RpcRequest.__init__(self, 'NAS', '2017-06-26', 'ListDirectoriesAndFiles','NAS')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_DirectoryOnly(self):
+	def get_DirectoryOnly(self): # Boolean
 		return self.get_query_params().get('DirectoryOnly')
 
-	def set_DirectoryOnly(self,DirectoryOnly):
-		self.add_query_param('DirectoryOnly',DirectoryOnly)
-
-	def get_StorageType(self):
+	def set_DirectoryOnly(self, DirectoryOnly):  # Boolean
+		self.add_query_param('DirectoryOnly', DirectoryOnly)
+	def get_StorageType(self): # String
 		return self.get_query_params().get('StorageType')
 
-	def set_StorageType(self,StorageType):
-		self.add_query_param('StorageType',StorageType)
-
-	def get_Path(self):
+	def set_StorageType(self, StorageType):  # String
+		self.add_query_param('StorageType', StorageType)
+	def get_Path(self): # String
 		return self.get_query_params().get('Path')
 
-	def set_Path(self,Path):
-		self.add_query_param('Path',Path)
-
-	def get_NextToken(self):
+	def set_Path(self, Path):  # String
+		self.add_query_param('Path', Path)
+	def get_NextToken(self): # String
 		return self.get_query_params().get('NextToken')
 
-	def set_NextToken(self,NextToken):
-		self.add_query_param('NextToken',NextToken)
-
-	def get_FileSystemId(self):
+	def set_NextToken(self, NextToken):  # String
+		self.add_query_param('NextToken', NextToken)
+	def get_FileSystemId(self): # String
 		return self.get_query_params().get('FileSystemId')
 
-	def set_FileSystemId(self,FileSystemId):
-		self.add_query_param('FileSystemId',FileSystemId)
-
-	def get_MaxResults(self):
+	def set_FileSystemId(self, FileSystemId):  # String
+		self.add_query_param('FileSystemId', FileSystemId)
+	def get_MaxResults(self): # Long
 		return self.get_query_params().get('MaxResults')
 
-	def set_MaxResults(self,MaxResults):
-		self.add_query_param('MaxResults',MaxResults)
\ No newline at end of file
+	def set_MaxResults(self, MaxResults):  # Long
+		self.add_query_param('MaxResults', MaxResults)
