@@ -23,40 +23,36 @@ from aliyunsdknas.endpoint import endpoint_data
 class ModifyAutoSnapshotPolicyRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'NAS', '2017-06-26', 'ModifyAutoSnapshotPolicy')
+		RpcRequest.__init__(self, 'NAS', '2017-06-26', 'ModifyAutoSnapshotPolicy','NAS')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_AutoSnapshotPolicyId(self):
+	def get_AutoSnapshotPolicyId(self): # String
 		return self.get_query_params().get('AutoSnapshotPolicyId')
 
-	def set_AutoSnapshotPolicyId(self,AutoSnapshotPolicyId):
-		self.add_query_param('AutoSnapshotPolicyId',AutoSnapshotPolicyId)
-
-	def get_TimePoints(self):
+	def set_AutoSnapshotPolicyId(self, AutoSnapshotPolicyId):  # String
+		self.add_query_param('AutoSnapshotPolicyId', AutoSnapshotPolicyId)
+	def get_TimePoints(self): # String
 		return self.get_query_params().get('TimePoints')
 
-	def set_TimePoints(self,TimePoints):
-		self.add_query_param('TimePoints',TimePoints)
-
-	def get_RepeatWeekdays(self):
+	def set_TimePoints(self, TimePoints):  # String
+		self.add_query_param('TimePoints', TimePoints)
+	def get_RepeatWeekdays(self): # String
 		return self.get_query_params().get('RepeatWeekdays')
 
-	def set_RepeatWeekdays(self,RepeatWeekdays):
-		self.add_query_param('RepeatWeekdays',RepeatWeekdays)
-
-	def get_AutoSnapshotPolicyName(self):
+	def set_RepeatWeekdays(self, RepeatWeekdays):  # String
+		self.add_query_param('RepeatWeekdays', RepeatWeekdays)
+	def get_AutoSnapshotPolicyName(self): # String
 		return self.get_query_params().get('AutoSnapshotPolicyName')
 
-	def set_AutoSnapshotPolicyName(self,AutoSnapshotPolicyName):
-		self.add_query_param('AutoSnapshotPolicyName',AutoSnapshotPolicyName)
-
-	def get_RetentionDays(self):
+	def set_AutoSnapshotPolicyName(self, AutoSnapshotPolicyName):  # String
+		self.add_query_param('AutoSnapshotPolicyName', AutoSnapshotPolicyName)
+	def get_RetentionDays(self): # Integer
 		return self.get_query_params().get('RetentionDays')
 
-	def set_RetentionDays(self,RetentionDays):
-		self.add_query_param('RetentionDays',RetentionDays)
\ No newline at end of file
+	def set_RetentionDays(self, RetentionDays):  # Integer
+		self.add_query_param('RetentionDays', RetentionDays)
