@@ -23,9 +23,11 @@ from aliyunsdknas.endpoint import endpoint_data
 class OpenNASServiceRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'NAS', '2017-06-26', 'OpenNASService')
+		RpcRequest.__init__(self, 'NAS', '2017-06-26', 'OpenNASService','NAS')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
